summaryrefslogtreecommitdiff
path: root/nuttx/net/sendto.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-06-16 23:23:31 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-06-16 23:23:31 +0000
commit1bb56fb39d8db0c9a419818f82fa7e517cad55bc (patch)
treec6d5b6911e4ae7c85e4aa0b2f7a07c387c618d38 /nuttx/net/sendto.c
parent731994d0383c636e43644c3dc91b91b15745b345 (diff)
downloadpx4-nuttx-1bb56fb39d8db0c9a419818f82fa7e517cad55bc.tar.gz
px4-nuttx-1bb56fb39d8db0c9a419818f82fa7e517cad55bc.tar.bz2
px4-nuttx-1bb56fb39d8db0c9a419818f82fa7e517cad55bc.zip
Reserved word 'private' in C header files is a problem for C++
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@1890 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/net/sendto.c')
-rw-r--r--nuttx/net/sendto.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/net/sendto.c b/nuttx/net/sendto.c
index 102b49797..d74275ae7 100644
--- a/nuttx/net/sendto.c
+++ b/nuttx/net/sendto.c
@@ -1,7 +1,7 @@
/****************************************************************************
* net/sendto.c
*
- * Copyright (C) 2007, 2008 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2007-2009 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <spudmonkey@racsa.co.cr>
*
* Redistribution and use in source and binary forms, with or without
@@ -82,7 +82,7 @@ struct sendto_s
* Parameters:
* dev The sructure of the network driver that caused the interrupt
* conn An instance of the UDP connection structure cast to void *
* pvprivate An instance of struct sendto_s cast to void*
* flags Set of events describing why the callback was invoked
*
* Returned Value:
@@ -94,9 +94,9 @@ struct sendto_s
****************************************************************************/
#ifdef CONFIG_NET_UDP
-static uint16 sendto_interrupt(struct uip_driver_s *dev, void *conn, void *pvprivate, uint16 flags)
+static uint16 sendto_interrupt(struct uip_driver_s *dev, void *conn, void *pvpriv, uint16 flags)
{
- struct sendto_s *pstate = (struct sendto_s *)pvprivate;
+ struct sendto_s *pstate = (struct sendto_s *)pvpriv;
nvdbg("flags: %04x\n", flags);
if (pstate)
@@ -138,7 +138,7 @@ static uint16 sendto_interrupt(struct uip_driver_s *dev, void *conn, void *pvpri
/* Don't allow any further call backs. */
pstate->st_cb->flags = 0;
- pstate->st_cb->private = NULL;
+ pstate->st_cb->priv = NULL;
pstate->st_cb->event = NULL;
/* Wake up the waiting thread */
@@ -315,7 +315,7 @@ ssize_t sendto(int sockfd, const void *buf, size_t len, int flags,
if (state.st_cb)
{
state.st_cb->flags = UIP_POLL|UIP_CLOSE|UIP_ABORT|UIP_TIMEDOUT;
- state.st_cb->private = (void*)&state;
+ state.st_cb->priv = (void*)&state;
state.st_cb->event = sendto_interrupt;
/* Enable the UDP socket */
@@ -82,7 +82,7 @@ struct sendto_s
* dev The sructure of the network driver that caused the interrupt
* conn An instance of the UDP connection structure cast to void *
- * pvprivate An instance of struct sendto_s cast to void*
+ * pvpriv An instance of struct sendto_s cast to void*
* flags Set of events describing why the callback was invoked
*